@@ -7,7 +7,7 @@ use warnings;
 require DCOP;
 our @ISA = qw(DCOP);
 
-our $VERSION = '0.01';
+our $VERSION = '0.03';
 
 sub new {
 	my $proto = shift;
@@ -20,7 +20,6 @@ sub new {
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -39,20 +38,13 @@ since Kde3.4's perl bindings are disabled. This suite talks to 'dcop'.
 DCOP::Amarok talks directly to the player object of amaroK. This is meant to be a
 superclass for DcoP::Amarok::Player.
 
-=head2 EXPORT
-
-None by default.
-
-=head1 SEE ALSO
-
-
 =head1 AUTHOR
 
-Juan C. Müller, E<lt>jcmuller@gmail.com<gt>
+Juan C. Muller, E<lt>jcmuller@gmail.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2005 by Juan C. Müller
+Copyright 2005 by Juan C. Muller
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
